pub struct Core {
pub debug: bool,
pub window: Window,
pub applet: Context,
/* private fields */
}Expand description
COSMIC-specific application settings
Fields
debug: boolEnables debug features in cosmic/iced.
window: Windowapplet: Contextapplet only.Implementations
Sourceimpl Core
impl Core
Sourcepub const fn is_condensed(&self) -> bool
pub const fn is_condensed(&self) -> bool
Whether the window is too small for the nav bar + main content.
Sourcepub const fn scale_factor(&self) -> f32
pub const fn scale_factor(&self) -> f32
The scaling factor used by the application.
Enable or disable keyboard navigation
Enable or disable keyboard navigation
Sourcepub fn set_header_title(&mut self, title: String)
pub fn set_header_title(&mut self, title: String)
Set header bar title
pub fn set_show_context(&mut self, show: bool)
pub fn main_window_is(&self, id: Id) -> bool
Whether the nav panel is visible or not
Sourcepub const fn system_theme(&self) -> &Theme
pub const fn system_theme(&self) -> &Theme
Get the current system theme
Sourcepub const fn system_theme_mode(&self) -> ThemeMode
pub const fn system_theme_mode(&self) -> ThemeMode
Get the current system theme mode
pub fn watch_config<T: CosmicConfigEntry + Send + Sync + Default + 'static + Clone + PartialEq>( &self, config_id: &'static str, ) -> Subscription<Update<T>>
pub fn watch_state<T: CosmicConfigEntry + Send + Sync + Default + 'static + Clone + PartialEq>( &self, state_id: &'static str, ) -> Subscription<Update<T>>
Sourcepub fn focused_window(&self) -> Option<Id>
pub fn focused_window(&self) -> Option<Id>
Get the current focused window if it exists
Sourcepub fn focus_chain(&self) -> &[Id]
pub fn focus_chain(&self) -> &[Id]
Get the current focus chain of windows
Sourcepub fn system_is_dark(&self) -> bool
pub fn system_is_dark(&self) -> bool
Whether the application should use a dark theme, according to the system
Sourcepub fn main_window_id(&self) -> Option<Id>
pub fn main_window_id(&self) -> Option<Id>
The Id of the main window
Sourcepub fn set_main_window_id(&mut self, id: Option<Id>) -> Option<Id>
pub fn set_main_window_id(&mut self, id: Option<Id>) -> Option<Id>
Reset the tracked main window to a new value
pub fn drag<M: Send + 'static>(&self, id: Option<Id>) -> Task<M>
winit only.pub fn maximize<M: Send + 'static>( &self, id: Option<Id>, maximized: bool, ) -> Task<M>
winit only.pub fn minimize<M: Send + 'static>(&self, id: Option<Id>) -> Task<M>
winit only.pub fn set_title<M: Send + 'static>( &self, id: Option<Id>, title: String, ) -> Task<M>
winit only.pub fn set_windowed<M: Send + 'static>(&self, id: Option<Id>) -> Task<M>
winit only.pub fn toggle_maximize<M: Send + 'static>(&self, id: Option<Id>) -> Task<M>
winit only.pub fn sync_window_border_radii_to_theme(&self) -> bool
wayland_platform only.pub fn set_auto_blur(&mut self, auto_blur: BitFlags<Auto>)
pub fn auto_blur(&self) -> BitFlags<Auto>
Sourcepub fn frosted(&self, theme: &Theme) -> bool
pub fn frosted(&self, theme: &Theme) -> bool
Whether the active theme’s frosted (blur) styling should apply to this app’s surfaces.
pub fn set_auto_corner_radius(&mut self, auto_corner_radius: BitFlags<Auto>)
pub fn auto_corner_radius(&self) -> BitFlags<Auto>
pub fn set_app_type(&mut self, app_type: AppType)
pub fn app_type(&self) -> AppType
pub fn blur( &self, theme: &Theme, surface_id_wrapper: Option<SurfaceIdWrapper>, ) -> bool
winit only.Trait Implementations